@@ -25,7 +25,7 @@ D_Parser *new_D_Parser(struct D_ParserTables *t, int sizeof_ParseNode_User){
 void   free_D_Parser (D_Parser *p ){
   static void   (*fun)(D_Parser* )=NULL;
   if (fun == NULL) fun = (void   (*)(D_Parser* )) R_GetCCallable("dparser","free_D_Parser ");
-  fun(p );
+  return fun(p );
 }
 
 D_ParseNode *dparse(D_Parser *p, char *buf, int buf_len){
@@ -361,19 +361,19 @@ D_Pass *find_pass(Grammar *g, char *start, char *end){
 void   conditional_EBNF (Grammar *g ){
   static void   (*fun)(Grammar* )=NULL;
   if (fun == NULL) fun = (void   (*)(Grammar* )) R_GetCCallable("dparser","conditional_EBNF ");
-  fun(g );
+  return fun(g );
 }
 
 void   star_EBNF (Grammar *g ){
   static void   (*fun)(Grammar* )=NULL;
   if (fun == NULL) fun = (void   (*)(Grammar* )) R_GetCCallable("dparser","star_EBNF ");
-  fun(g );
+  return fun(g );
 }
 
 void   plus_EBNF (Grammar *g ){
   static void   (*fun)(Grammar* )=NULL;
   if (fun == NULL) fun = (void   (*)(Grammar* )) R_GetCCallable("dparser","plus_EBNF ");
-  fun(g );
+  return fun(g );
 }
 
 void rep_EBNF(Grammar *g, int minimum, int maximum){
@@ -511,7 +511,7 @@ int set_union(void *v, void *vv){
 void *set_add_fn(void *v, void *t, hash_fns_t *fns){
   static void *(*fun)(void*, void*, hash_fns_t*)=NULL;
   if (fun == NULL) fun = (void* (*)(void*, void*, hash_fns_t*)) R_GetCCallable("dparser","set_add_fn");
-  fun(v, t, fns);
+  return fun(v, t, fns);
 }
 
 void set_union_fn(void *v, void *vv, hash_fns_t *fns){
