@@ -1645,8 +1645,8 @@ write_header(Grammar *g, char *base_pathname, char *tag) {
     if (!hfp)
       d_fail("unable to open `%s` for write\n", pathname);
     d_version(ver);
-fprintf(hfp, "	/*\n  Generated by R\'s mkdparse a port of Make DParser Version %s\n", ver);
-	fprintf(hfp,"  R available at https://github.com/mattfidler/dparser-R\n");
+fprintf(hfp, "/*\n  Generated by R\'s mkdparse a port of Make DParser Version %s\n", ver);
+	fprintf(hfp,"  R available at https://github.com/nlmixrdevelopment/dparser-R\n");
 	fprintf(hfp,"  Original dparser Available at http://dparser.sf.net\n*/\n\n\n");
 	if (d_use_r_headers){
 		fprintf(hfp,"\n\n#include <R.h>\n#include <Rinternals.h>\n#define printf Rprintf\n\n");
@@ -1830,8 +1830,8 @@ write_parser_tables_internal(Grammar *g, char *base_pathname, char *tag, int bin
     char ver[128];
     int header = write_header(g, base_pathname, tag);
     d_version(ver);
-fprintf(fp, "	/*\n  Generated by R\'s mkdparse a port of Make DParser Version %s\n", ver);
-	fprintf(fp,"  R available at https://github.com/mattfidler/dparser-R\n");
+fprintf(fp, "/*\n  Generated by R\'s mkdparse a port of Make DParser Version %s\n", ver);
+	fprintf(fp,"  R available at https://github.com/nlmixrdevelopment/dparser-R\n");
 	fprintf(fp,"  Original dparser Available at http://dparser.sf.net\n*/\n\n\n");
 	if (d_use_r_headers){
 		fprintf(fp,"\n\n#include <R.h>\n#include <Rinternals.h>\n#define printf Rprintf\n\n");
